{% extends "base.html" %}

{% block title %}Erreur {{ code }} | {{ super() }}{% endblock %}

{% block content %}

<div class="alert alert-danger" role="alert">
{% if code == 403 %}
<strong>Accès interdit</strong>. L'accès à cette page ne vous est pas autorisé.
Laissez tomber, y'a rien à faire.
{% elif code == 404 %}
<strong>Page introuvable</strong>. Merci de vérifier l'adresse ou de nous
signaler sur quel lien vous avez cliqué.
{% endif %}
</div>

{% endblock %}

