
/*
 * Graph
 */

#graph {
    border: 1px solid black;
    height: 700px;
}

#graph img.ajaxloader {
    display: block;
    margin: 2em auto 0 auto;
}

#graph > svg {
    display: block;
    margin: 0 auto;
}

.node circle {
    cursor: move;
    stroke: #bbbbbb;
    stroke-width: 1.5px;
    fill: #eeeeee;
}

.node rect {
    fill: #ffffff;
    opacity: 0.5;
}
.node text {
    font: 12px sans-serif;
    pointer-events: none;
    text-anchor: middle;
}
/* circles */
.node.circle-0 text,
.node.circle-1 text {
    font-weight: bold;
    font-size: 14px;
}
.node.circle-2 text {
    font-size: 14px;
}
.node.circle-3 text {
    font-size: 13px;
}
/* abbreviations for anonymous state */
.node .full,
.node .abbrev {
    display: none;
}

path.link {
    fill: none;
    stroke: #9ecae1;
    stroke-width: 1.5px;
}

path.link.dotted {
    stroke-dasharray: 5 5;
}


/*
 * Legend
 */

#legend {
    margin-top: 1em;
    text-align: center;
    font-size: 90%;
}
#legend ul {
    display: inline;
    padding: 0;
    margin: 0;
    list-style-type: none;
}
#legend ul li {
    display: inline-block;
    margin-left: 1em;
}
#legend ul li span {
    display: inline-block;
    width: 1em;
    height: 1em;
    vertical-align: baseline;
}
#legend p {
    margin-top: 0.2em;
    margin-bottom: 0;
}
#legend button,
#legend label {
    margin-left: 0.8em;
}

/* Anonymous button */
#btn-anonymous span.glyphicon-eye-open,
#btn-anonymous.active span.glyphicon-eye-close {
    display: inline;
}
#btn-anonymous.active span.glyphicon-eye-open,
#btn-anonymous span.glyphicon-eye-close {
    display: none;
}


/*
 * Generic
 */

.flashmessage > div {
    text-align: center;
}
.flashmessage .alert {
    display: inline-block;
}
.flashmessage.dismissible {
    position: absolute;
    left: 50%;
}
.flashmessage.dismissible .alert-dismissible {
    position: relative;
    left: -50%;
    z-index: 5;
}

.navbar-brand img { display: inline }

.loadable {
    width: 16px;
    height: 16px;
    margin: 5px auto;
    background-image: url("ajax-loader.gif");
}


/*
 * Front page
 */

img.signin {
    cursor: pointer;
    vertical-align: middle;
}

div.newgraph {
    margin-top: 4em;
}


/*
 * Admin
 */

table.table.table-centered {
    width: auto;
    margin-left: auto;
    margin-right: auto;
}
table.table.table-centered th {
    text-align: center;
}
table.table.table-centered td {
    padding-left: 1em;
    padding-right: 1em;
    vertical-align: middle;
}

input.form-control.color {
    width: 5em;
}



/*
 * Footer
 */
#footer {
    margin-top: 4em;
}
#footer p {
    text-align: center;
    font-size: 90%;
    color: #777;
}


/*
 * Autocomplete
 */
.tt-dropdown-menu {
    border-left: 1px solid #66afe9;
    border-right: 1px solid #66afe9;
    border-bottom: 1px solid #66afe9;
    padding: 2px 0px;
    border-radius: 3px;
    background-color: #ffffff;
}
.tt-dropdown-menu .tt-suggestion p {
    padding: 0;
    margin: 0;
    font-size: 12px;
}
.tt-dropdown-menu .tt-suggestion {
    padding: 0.2em 1.5em;
    cursor: pointer;
}
.tt-dropdown-menu .tt-cursor {
    background-color: #eeeeee;
}
